@@ -3,14 +3,13 @@ import gc
 import numpy as np
 from datetime import datetime, timedelta
 from pysrt import SubRipTime, SubRipFile
-from typing import Tuple
-from .singleton import Singleton
+from typing import Tuple, Optional
 from .subtitle import Subtitle
-from .exception import UnsupportedFormatException, TerminalException
+from .exception import TerminalException
 from .logger import Logger
 
 
-class FeatureEmbedder():
+class FeatureEmbedder(object):
     """Audio and subtitle feature embedding.
     """
 
@@ -47,13 +46,6 @@ class FeatureEmbedder():
             1.0 / frequency
         ) * hop_len  # 1 item = 1/16000 seg = 32 ms
 
-        # freeze the object after creation
-        def __setattr__(self, *args):
-            raise NotImplementedError("Cannot modify the immutable object")
-
-        def __delattr__(self, *args):
-            raise NotImplementedError("Cannot modify the immutable object")
-
     @property
     def n_mfcc(self) -> int:
         """Get the number of MFCC components.
@@ -244,8 +236,9 @@ class FeatureEmbedder():
         self,
         audio_file_path: str,
         subtitle_file_path: str,
-        subtitles: SubRipFile = None,
-        ignore_sound_effects: bool = False,
+        subtitles: Optional[SubRipFile] = None,
+        sound_effect_start_marker: Optional[str] = None,
+        sound_effect_end_marker: Optional[str] = None,
     ) -> Tuple[np.ndarray, np.ndarray]:
         """Generate a train dataset from an audio file and its subtitles
 
@@ -254,8 +247,9 @@ class FeatureEmbedder():
             subtitle_file_path {string} -- The path to the subtitle file.
 
         Keyword Arguments:
-            subtitles {pysrt.SubRipFile} -- The SubRipFile object (default: {None})
-            ignore_sound_effects {boolean} -- Ignore subtitles which are sound effects.
+            subtitles {pysrt.SubRipFile} -- The SubRipFile object (default: {None}).
+            sound_effect_start_marker: {string} -- A string indicating the start of the ignored sound effect (default: {None}).
+            sound_effect_end_marker: {string} -- A string indicating the end of the ignored sound effect (default: {None}).
 
         Returns:
             tuple -- The training data and the training lables.
@@ -270,20 +264,16 @@ class FeatureEmbedder():
         if subtitle_file_path is None and subtitles is not None:
             subs = subtitles
         elif subtitle_file_path is not None:
-            try:
-                subs = Subtitle.load(subtitle_file_path).subs
-                FeatureEmbedder.__LOGGER.info(
-                    "Subtitle file loaded: {}".format(subtitle_file_path)
-                )
-            except UnsupportedFormatException:
-                raise
+            subs = Subtitle.load(subtitle_file_path).subs
+            FeatureEmbedder.__LOGGER.info("Subtitle file loaded: {}".format(subtitle_file_path))
         else:
+            FeatureEmbedder.__LOGGER.error("Subtitles are missing")
             raise TerminalException("Subtitles are missing")
 
-        if ignore_sound_effects:
+        if sound_effect_start_marker is not None:
             original_size = len(subs)
             subs = Subtitle.remove_sound_effects_by_affixes(
-                subs, se_prefix="(", se_suffix=")"
+                subs, se_prefix=sound_effect_start_marker, se_suffix=sound_effect_end_marker
             )
             subs = Subtitle.remove_sound_effects_by_case(
                 subs, se_uppercase=True
