@@ -1,8 +1,10 @@
-# works in Python 2 & 3
-class _Singleton(type):
+from typing import Dict, Any
+
+
+class _Singleton(type):  # type: ignore
     """ A metaclass that creates a Singleton base class when called. """
 
-    _instances = {}
+    _instances: Dict[Any, Any] = {}
 
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances:
@@ -12,5 +14,5 @@ class _Singleton(type):
         return cls._instances[cls]
 
 
-class Singleton(_Singleton("SingletonMeta", (object,), {})):
+class Singleton(_Singleton("SingletonMeta", (object,), {})):  # type: ignore
     pass
