@@ -166,7 +166,7 @@ class Utils(object):
         Utils.remove_trailing_newlines(new_srt_file_path, encoding)
 
     @staticmethod
-    def srt2microdvd(srt_file_path: str, microdvd_file_path: Optional[str] = None, frame_rate: float = 25.0):
+    def srt2microdvd(srt_file_path: str, microdvd_file_path: Optional[str] = None, frame_rate: Optional[float] = 25.0):
         """Convert SubRip subtitles to MicroDVD subtitles.
 
         Arguments:
@@ -407,6 +407,9 @@ class Utils(object):
         """
 
         with open(subtitle_file_path, "rb") as file:
+            # raw = b"".join([file.readline() for _ in range(10)])
+            # Sampling with 10 lines did not work well enough for large subtitle files
+            # and hence this less memory-efficient solution:
             raw = b"".join(file.readlines())
 
         detected = cchardet.detect(raw)
